define(
//begin v1.x content
({
	insertTableTitle: "插入表",
	modifyTableTitle: "修改表",
	rows: "行：",
	columns: "列：",
	align: "对齐：",
	cellPadding: "单元格边距：",
	cellSpacing: "单元格间距：",
	tableWidth: "表宽度：",
	backgroundColor: "背景色：",
	borderColor: "边框色：",
	borderThickness: "边框厚度",
	percent: "百分比",
	pixels: "像素",
	"default": "缺省值",
	left: "左边对齐",
	center: "中间对齐",
	right: "右边对齐",
	buttonSet: "设置", // translated elsewhere?
	buttonInsert: "插入",
	buttonCancel: "取消",

	selectTableLabel: "选择表",
	insertTableRowBeforeLabel: "在之前添加行",
	insertTableRowAfterLabel: "在之后添加行",
	insertTableColumnBeforeLabel: "在之前添加列",
	insertTableColumnAfterLabel: "在之后添加列",
	deleteTableRowLabel: "删除行",
	deleteTableColumnLabel: "删除列"
})

//end v1.x content
);
